@@ -1,6 +1,7 @@
 import json
 import logging
 import datetime
+import traceback
 from base64 import b64decode, b64encode
 from binascii import a2b_hex, b2a_hex
 from struct import *
@@ -62,7 +63,7 @@ class MessageBody:
             x = 0
             while x < len(payload):
                 uuid = self.getUuid(payload[x:x+16])
-                #_LOGGER.debug("  uuid: {0} {1} {2}".format(type(uuid), len(uuid), uuid))
+                _LOGGER.debug("  uuid: {0} {1} {2}".format(type(uuid), len(uuid), uuid))
 
                 e = payload[x+16:x+24]
                 #_LOGGER.debug("  e: {0} {1} {2}".format(type(e), len(e), e))
@@ -84,6 +85,7 @@ class MessageBody:
 
                     except Exception as ex:
                         _LOGGER.error(ex)
+                        _LOGGER.error(traceback.format_exc())
 
                 else:
                     category = 'unknown'
